"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LogRateAnalysisContentWrapper = void 0;
var _react = _interopRequireDefault(require("react"));
var _lodash = require("lodash");
var _mlLocalStorage = require("@kbn/ml-local-storage");
var _mlUrlState = require("@kbn/ml-url-state");
var _public = require("@kbn/kibana-utils-plugin/public");
var _mlDatePicker = require("@kbn/ml-date-picker");
var _common = require("@kbn/data-plugin/common");
var _state = require("@kbn/aiops-log-rate-analysis/state");
var _use_filters_query = require("../../../hooks/use_filters_query");
var _time_series_dataview_check = require("../../../application/utils/time_series_dataview_check");
var _use_aiops_app_context = require("../../../hooks/use_aiops_app_context");
var _use_data_source = require("../../../hooks/use_data_source");
var _storage = require("../../../types/storage");
var _log_rate_analysis_document_count_chart_data = require("./log_rate_analysis_document_count_chart_data");
var _log_rate_analysis_content = require("./log_rate_analysis_content");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const localStorage = new _public.Storage(window.localStorage);

/**
 * Props for the LogRateAnalysisContentWrapper component.
 */

const LogRateAnalysisContentWrapper = ({
  dataView,
  appContextValue,
  initialAnalysisStart,
  timeRange,
  esSearchQuery,
  barColorOverride,
  barHighlightColorOverride,
  onAnalysisCompleted,
  showFrozenDataTierChoice = true
}) => {
  if (!dataView) return null;
  const warning = (0, _time_series_dataview_check.timeSeriesDataViewWarning)(dataView, 'log_rate_analysis');
  if (warning !== null) {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, warning);
  }
  const datePickerDeps = {
    ...(0, _lodash.pick)(appContextValue, ['data', 'http', 'notifications', 'theme', 'uiSettings', 'userProfile', 'i18n']),
    uiSettingsKeys: _common.UI_SETTINGS,
    showFrozenDataTierChoice
  };
  return /*#__PURE__*/_react.default.createElement(_use_aiops_app_context.AiopsAppContext.Provider, {
    value: appContextValue
  }, /*#__PURE__*/_react.default.createElement(_mlUrlState.UrlStateProvider, null, /*#__PURE__*/_react.default.createElement(_use_data_source.DataSourceContext.Provider, {
    value: {
      dataView,
      savedSearch: null
    }
  }, /*#__PURE__*/_react.default.createElement(_state.LogRateAnalysisReduxProvider, {
    initialAnalysisStart: initialAnalysisStart
  }, /*#__PURE__*/_react.default.createElement(_mlLocalStorage.StorageContextProvider, {
    storage: localStorage,
    storageKeys: _storage.AIOPS_STORAGE_KEYS
  }, /*#__PURE__*/_react.default.createElement(_mlDatePicker.DatePickerContextProvider, datePickerDeps, /*#__PURE__*/_react.default.createElement(_log_rate_analysis_document_count_chart_data.LogRateAnalysisDocumentCountChartData, {
    timeRange: timeRange,
    esSearchQuery: esSearchQuery
  }), /*#__PURE__*/_react.default.createElement(_use_filters_query.FilterQueryContextProvider, null, /*#__PURE__*/_react.default.createElement(_log_rate_analysis_content.LogRateAnalysisContent, {
    esSearchQuery: esSearchQuery,
    barColorOverride: barColorOverride,
    barHighlightColorOverride: barHighlightColorOverride,
    onAnalysisCompleted: onAnalysisCompleted
  }))))))));
};
exports.LogRateAnalysisContentWrapper = LogRateAnalysisContentWrapper;