"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.bulkUntrackAlertsByQueryRoute = void 0;
var _bulk_untrack_by_query = require("../../../../../common/routes/rule/apis/bulk_untrack_by_query");
var _lib = require("../../../../lib");
var _lib2 = require("../../../lib");
var _types = require("../../../../types");
var _transforms = require("./transforms");
var _constants = require("../../../constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const bulkUntrackAlertsByQueryRoute = (router, licenseState) => {
  router.post({
    path: `${_types.INTERNAL_BASE_ALERTING_API_PATH}/alerts/_bulk_untrack_by_query`,
    security: _constants.DEFAULT_ALERTING_ROUTE_SECURITY,
    options: {
      access: 'internal'
    },
    validate: {
      body: _bulk_untrack_by_query.bulkUntrackByQueryBodySchemaV1
    }
  }, router.handleLegacyErrors((0, _lib2.verifyAccessAndContext)(licenseState, async function (context, req, res) {
    const alertingContext = await context.alerting;
    const rulesClient = await alertingContext.getRulesClient();
    const body = req.body;
    try {
      await rulesClient.bulkUntrackAlerts({
        ...(0, _transforms.transformBulkUntrackAlertsByQueryBodyV1)(body),
        isUsingQuery: true
      });
      return res.noContent();
    } catch (e) {
      if (e instanceof _lib.RuleTypeDisabledError) {
        return e.sendResponse(res);
      }
      throw e;
    }
  })));
};
exports.bulkUntrackAlertsByQueryRoute = bulkUntrackAlertsByQueryRoute;