"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Metrics = Metrics;
var _react = _interopRequireDefault(require("react"));
var _agent_guards = require("@kbn/elastic-agent-utils/src/agent_guards");
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _agent_name = require("../../../../common/agent_name");
var _use_apm_service_context = require("../../../context/apm_service/use_apm_service_context");
var _serverless_metrics = require("./serverless_metrics");
var _service_metrics = require("./service_metrics");
var _static_dashboard = require("./static_dashboard");
var _helper = require("./static_dashboard/helper");
var _use_adhoc_apm_data_view = require("../../../hooks/use_adhoc_apm_data_view");
var _get_signal_type = require("../../../utils/get_signal_type");
var _service_tab_empty_state = require("../service_tab_empty_state");
var _jvm_metrics_overview = require("./jvm_metrics_overview");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function Metrics() {
  const {
    agentName,
    runtimeName,
    serverlessType,
    serviceEntitySummary,
    telemetrySdkName,
    telemetrySdkLanguage
  } = (0, _use_apm_service_context.useApmServiceContext)();
  const isAWSLambda = (0, _agent_name.isAWSLambdaAgentName)(serverlessType);
  const {
    dataView
  } = (0, _use_adhoc_apm_data_view.useAdHocApmDataView)();
  const hasDashboardFile = (0, _helper.hasDashboard)({
    agentName,
    telemetrySdkName,
    telemetrySdkLanguage
  });
  const hasLogsOnlySignal = (serviceEntitySummary === null || serviceEntitySummary === void 0 ? void 0 : serviceEntitySummary.dataStreamTypes) && (0, _get_signal_type.isLogsOnlySignal)(serviceEntitySummary.dataStreamTypes);
  if (hasLogsOnlySignal) {
    return /*#__PURE__*/_react.default.createElement(_service_tab_empty_state.ServiceTabEmptyState, {
      id: "metrics"
    });
  }
  if (isAWSLambda) {
    return /*#__PURE__*/_react.default.createElement(_serverless_metrics.ServerlessMetrics, null);
  }
  if (!hasDashboardFile && !(0, _agent_guards.isElasticAgentName)(agentName !== null && agentName !== void 0 ? agentName : '')) {
    return /*#__PURE__*/_react.default.createElement(_eui.EuiCallOut, {
      title: _i18n.i18n.translate('xpack.apm.metrics.emptyState.title', {
        defaultMessage: 'Runtime metrics are not available for this Agent / SDK type.'
      }),
      iconType: "iInCircle",
      "data-test-subj": "apmMetricsNoDashboardFound"
    });
  }
  if (hasDashboardFile && dataView) {
    return /*#__PURE__*/_react.default.createElement(_static_dashboard.JsonMetricsDashboard, {
      agentName: agentName,
      telemetrySdkName: telemetrySdkName,
      telemetrySdkLanguage: telemetrySdkLanguage,
      runtimeName: runtimeName,
      serverlessType: serverlessType,
      dataView: dataView
    });
  }
  if (!isAWSLambda && (0, _agent_guards.isJRubyAgentName)(agentName, runtimeName)) {
    return /*#__PURE__*/_react.default.createElement(_jvm_metrics_overview.JvmMetricsOverview, null);
  }
  return /*#__PURE__*/_react.default.createElement(_service_metrics.ServiceMetrics, null);
}