"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GroupDetails = GroupDetails;
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _react = _interopRequireWildcard(require("react"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function GroupDetails({
  isEdit,
  serviceGroup,
  onCloseModal,
  onClickNext,
  onDeleteGroup,
  isLoading,
  titleId
}) {
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const initialColor = (serviceGroup === null || serviceGroup === void 0 ? void 0 : serviceGroup.color) || euiTheme.colors.backgroundFilledPrimary;
  const [name, setName] = (0, _react.useState)(serviceGroup === null || serviceGroup === void 0 ? void 0 : serviceGroup.groupName);
  const [color, setColor, colorPickerErrors] = (0, _eui.useColorPickerState)(initialColor);
  const [description, setDescription] = (0, _react.useState)(serviceGroup === null || serviceGroup === void 0 ? void 0 : serviceGroup.description);
  const isNamePristine = name === (serviceGroup === null || serviceGroup === void 0 ? void 0 : serviceGroup.groupName);
  const isColorPristine = color === initialColor;
  (0, _react.useEffect)(() => {
    if (serviceGroup) {
      setName(serviceGroup.groupName);
      if (serviceGroup.color) {
        setColor(serviceGroup.color, {
          hex: serviceGroup.color,
          isValid: (0, _eui.isValidHex)(color)
        });
      }
      setDescription(serviceGroup.description);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [serviceGroup]); // setColor omitted: new reference each render

  const isInvalidColor = !!(colorPickerErrors !== null && colorPickerErrors !== void 0 && colorPickerErrors.length) || !(0, _eui.isValidHex)(color);
  const isInvalidName = !name;
  const isInvalid = isInvalidName || isInvalidColor;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiModalHeader, null, /*#__PURE__*/_react.default.createElement(_eui.EuiModalHeaderTitle, {
    id: titleId
  }, isEdit ? _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.edit.title', {
    defaultMessage: 'Edit group'
  }) : _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.create.title', {
    defaultMessage: 'Create group'
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiModalBody, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
    direction: "column",
    gutterSize: "s"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.name', {
      defaultMessage: 'Name'
    }),
    isInvalid: !isNamePristine && isInvalidName,
    error: !isNamePristine && isInvalidName ? _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.invalidNameError', {
      defaultMessage: 'Please provide a valid name value'
    }) : undefined
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldText, {
    "data-test-subj": "apmGroupNameInput",
    value: name || '',
    onChange: e => {
      setName(e.target.value);
    },
    isInvalid: !isNamePristine && isInvalidName
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    label: _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.color', {
      defaultMessage: 'Color'
    }),
    isInvalid: !isColorPristine && isInvalidColor,
    error: !isColorPristine && isInvalidColor ? _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.invalidColorError', {
      defaultMessage: 'Please provide a valid HEX color value'
    }) : undefined
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiColorPicker, {
    onChange: setColor,
    color: color,
    isInvalid: !isColorPristine && isInvalidColor
  }))))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFormRow, {
    fullWidth: true,
    label: _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.description', {
      defaultMessage: 'Description'
    }),
    labelAppend: /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
      size: "xs",
      color: "subdued"
    }, _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.description.optional', {
      defaultMessage: 'Optional'
    }))
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFieldText, {
    "data-test-subj": "apmGroupDetailsFieldText",
    fullWidth: true,
    value: description || '',
    onChange: e => {
      setDescription(e.target.value);
    }
  }))))), /*#__PURE__*/_react.default.createElement(_eui.EuiModalFooter, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, null, isEdit && /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    iconType: "trash",
    iconSide: "left",
    onClick: () => {
      onDeleteGroup();
    },
    color: "danger",
    isLoading: isLoading,
    isDisabled: isLoading,
    "data-test-subj": "apmDeleteGroupButton"
  }, _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.deleteGroup', {
    defaultMessage: 'Delete group'
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false,
    style: {
      marginLeft: 'auto'
    }
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    "data-test-subj": "apmGroupDetailsCancelButton",
    onClick: onCloseModal,
    isLoading: isLoading,
    isDisabled: isLoading
  }, _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.cancel', {
    defaultMessage: 'Cancel'
  }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButton, {
    "data-test-subj": "apmGroupDetailsSelectServicesButton",
    fill: true,
    iconType: "sortRight",
    iconSide: "right",
    onClick: () => {
      var _serviceGroup$kuery;
      onClickNext({
        groupName: name || '',
        color,
        description,
        kuery: (_serviceGroup$kuery = serviceGroup === null || serviceGroup === void 0 ? void 0 : serviceGroup.kuery) !== null && _serviceGroup$kuery !== void 0 ? _serviceGroup$kuery : ''
      });
    },
    isLoading: isLoading,
    isDisabled: isInvalid || isLoading
  }, _i18n.i18n.translate('xpack.apm.serviceGroups.groupDetailsForm.selectServices', {
    defaultMessage: 'Select services'
  }))))));
}