"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.agentExplorerRouteRepository = void 0;
var t = _interopRequireWildcard(require("io-ts"));
var _get_apm_event_client = require("../../lib/helpers/get_apm_event_client");
var _get_random_sampler = require("../../lib/helpers/get_random_sampler");
var _create_apm_server_route = require("../apm_routes/create_apm_server_route");
var _default_api_types = require("../default_api_types");
var _get_agents = require("./get_agents");
var _get_agent_instances = require("./get_agent_instances");
var _fetch_agents_latest_version = require("./fetch_agents_latest_version");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const agentExplorerRoute = (0, _create_apm_server_route.createApmServerRoute)({
  endpoint: 'GET /internal/apm/get_agents_per_service',
  security: {
    authz: {
      requiredPrivileges: ['apm']
    }
  },
  params: t.type({
    query: t.intersection([_default_api_types.environmentRt, _default_api_types.kueryRt, _default_api_types.rangeRt, _default_api_types.probabilityRt, t.partial({
      serviceName: t.string,
      agentLanguage: t.string
    })])
  }),
  async handler(resources) {
    const {
      params,
      request,
      core
    } = resources;
    const {
      environment,
      kuery,
      start,
      end,
      probability,
      serviceName,
      agentLanguage
    } = params.query;
    const coreStart = await core.start();
    const [apmEventClient, randomSampler] = await Promise.all([(0, _get_apm_event_client.getApmEventClient)(resources), (0, _get_random_sampler.getRandomSampler)({
      coreStart,
      request,
      probability
    })]);
    return (0, _get_agents.getAgents)({
      environment,
      serviceName,
      agentLanguage,
      kuery,
      apmEventClient,
      start,
      end,
      randomSampler
    });
  }
});
const latestAgentVersionsRoute = (0, _create_apm_server_route.createApmServerRoute)({
  endpoint: 'GET /internal/apm/get_latest_agent_versions',
  security: {
    authz: {
      requiredPrivileges: ['apm']
    }
  },
  async handler(resources) {
    const {
      logger,
      config
    } = resources;
    return (0, _fetch_agents_latest_version.fetchAgentsLatestVersion)(logger, config.latestAgentVersionsUrl);
  }
});
const agentExplorerInstanceRoute = (0, _create_apm_server_route.createApmServerRoute)({
  endpoint: 'GET /internal/apm/services/{serviceName}/agent_instances',
  security: {
    authz: {
      requiredPrivileges: ['apm']
    }
  },
  params: t.type({
    path: t.type({
      serviceName: t.string
    }),
    query: t.intersection([_default_api_types.environmentRt, _default_api_types.kueryRt, _default_api_types.rangeRt, _default_api_types.probabilityRt])
  }),
  async handler(resources) {
    const {
      params
    } = resources;
    const {
      environment,
      kuery,
      start,
      end
    } = params.query;
    const {
      serviceName
    } = params.path;
    const apmEventClient = await (0, _get_apm_event_client.getApmEventClient)(resources);
    return {
      items: await (0, _get_agent_instances.getAgentInstances)({
        environment,
        serviceName,
        kuery,
        apmEventClient,
        start,
        end
      })
    };
  }
});
const agentExplorerRouteRepository = exports.agentExplorerRouteRepository = {
  ...agentExplorerRoute,
  ...latestAgentVersionsRoute,
  ...agentExplorerInstanceRoute
};