"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.deleteAllCommentsRoute = void 0;
var _configSchema = require("@kbn/config-schema");
var _constants = require("../../../../common/constants");
var _create_cases_route = require("../create_cases_route");
var _error = require("../../../common/error");
var _constants2 = require("../constants");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const deleteAllCommentsRoute = exports.deleteAllCommentsRoute = (0, _create_cases_route.createCasesRoute)({
  method: 'delete',
  path: _constants.CASE_COMMENTS_URL,
  security: _constants2.DEFAULT_CASES_ROUTE_SECURITY,
  routerOptions: {
    access: 'public',
    summary: `Delete all case comments and alerts`,
    tags: ['oas-tag:cases'],
    description: 'Deletes all comments and alerts from a case.'
    // You must have `all` privileges for the **Cases** feature in the **Management**, **Observability**, or **Security** section of the Kibana feature privileges, depending on the owner of the cases you're deleting.
  },
  params: {
    params: _configSchema.schema.object({
      case_id: _configSchema.schema.string()
    })
  },
  handler: async ({
    context,
    request,
    response
  }) => {
    try {
      const caseContext = await context.cases;
      const client = await caseContext.getCasesClient();
      await client.attachments.deleteAll({
        caseID: request.params.case_id
      });
      return response.noContent();
    } catch (error) {
      throw (0, _error.createCaseError)({
        message: `Failed to delete all comments in route case id: ${request.params.case_id}: ${error}`,
        error
      });
    }
  }
});