"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OptionsListPopoverSuggestions = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _presentationPublishing = require("@kbn/presentation-publishing");
var _constants = require("../constants");
var _options_list_context_provider = require("../options_list_context_provider");
var _options_list_strings = require("../options_list_strings");
var _options_list_popover_empty_message = require("./options_list_popover_empty_message");
var _options_list_popover_suggestion_badge = require("./options_list_popover_suggestion_badge");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const OptionsListPopoverSuggestions = ({
  showOnlySelected
}) => {
  const {
    api,
    stateManager,
    displaySettings: {
      hideExists
    }
  } = (0, _options_list_context_provider.useOptionsListContext)();
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const [sort, searchString, existsSelected, searchTechnique, selectedOptions, fieldName, invalidSelections, availableOptions, totalCardinality, loading, fieldFormatter, allowExpensiveQueries] = (0, _presentationPublishing.useBatchedPublishingSubjects)(stateManager.sort, stateManager.searchString, stateManager.existsSelected, stateManager.searchTechnique, stateManager.selectedOptions, stateManager.fieldName, api.invalidSelections$, api.availableOptions$, api.totalCardinality$, api.dataLoading$, api.fieldFormatter, api.parentApi.allowExpensiveQueries$);
  const listRef = (0, _react.useRef)(null);
  const canLoadMoreSuggestions = (0, _react.useMemo)(() => allowExpensiveQueries && totalCardinality && !showOnlySelected // && searchString.valid
  ? (availableOptions !== null && availableOptions !== void 0 ? availableOptions : []).length < Math.min(totalCardinality, _constants.MAX_OPTIONS_LIST_REQUEST_SIZE) : false, [availableOptions, totalCardinality, showOnlySelected, allowExpensiveQueries]);
  const suggestions = (0, _react.useMemo)(() => {
    var _ref;
    return (_ref = showOnlySelected ? selectedOptions : availableOptions) !== null && _ref !== void 0 ? _ref : [];
  }, [availableOptions, selectedOptions, showOnlySelected]);
  const existsSelectableOption = (0, _react.useMemo)(() => {
    if (hideExists || !existsSelected && (showOnlySelected || (suggestions === null || suggestions === void 0 ? void 0 : suggestions.length) === 0)) return;
    return {
      key: 'exists-option',
      checked: existsSelected ? 'on' : undefined,
      label: _options_list_strings.OptionsListStrings.controlAndPopover.getExists(),
      className: 'optionsList__existsFilter',
      'data-test-subj': 'optionsList-control-selection-exists'
    };
  }, [suggestions, existsSelected, showOnlySelected, hideExists]);
  const [selectableOptions, setSelectableOptions] = (0, _react.useState)([]); // will be set in following useEffect
  (0, _react.useEffect)(() => {
    /* This useEffect makes selectableOptions responsive to search, show only selected, and clear selections */
    const options = suggestions.map(suggestion => {
      var _fieldFormatter, _suggestion;
      if (typeof suggestion !== 'object') {
        // this means that `showOnlySelected` is true, and doc count is not known when this is the case
        suggestion = {
          value: suggestion
        };
      }
      return {
        key: String(suggestion.value),
        label: String((_fieldFormatter = fieldFormatter(suggestion.value)) !== null && _fieldFormatter !== void 0 ? _fieldFormatter : suggestion.value),
        checked: (selectedOptions !== null && selectedOptions !== void 0 ? selectedOptions : []).includes(suggestion.value) ? 'on' : undefined,
        'data-test-subj': `optionsList-control-selection-${suggestion.value}`,
        className: showOnlySelected && invalidSelections.has(suggestion.value) ? 'optionsList__selectionInvalid' : 'optionsList__validSuggestion',
        append: !showOnlySelected && (_suggestion = suggestion) !== null && _suggestion !== void 0 && _suggestion.docCount ? /*#__PURE__*/_react.default.createElement(_options_list_popover_suggestion_badge.OptionsListPopoverSuggestionBadge, {
          documentCount: suggestion.docCount
        }) : undefined
      };
    });
    if (canLoadMoreSuggestions) {
      options.push({
        key: 'loading-option',
        'data-test-subj': 'optionslist--canLoadMore',
        className: 'optionslist--loadingMoreGroupLabel',
        label: _options_list_strings.OptionsListStrings.popover.getLoadingMoreMessage(),
        isGroupLabel: true
      });
    } else if (options.length === _constants.MAX_OPTIONS_LIST_REQUEST_SIZE) {
      options.push({
        key: 'no-more-option',
        className: 'optionslist--endOfOptionsGroupLabel',
        label: _options_list_strings.OptionsListStrings.popover.getAtEndOfOptionsMessage(),
        isGroupLabel: true
      });
    }
    setSelectableOptions(existsSelectableOption ? [existsSelectableOption, ...options] : options);
  }, [suggestions, availableOptions, showOnlySelected, selectedOptions, invalidSelections, existsSelectableOption, canLoadMoreSuggestions, fieldFormatter]);
  const loadMoreOptions = (0, _react.useCallback)(() => {
    var _listRef$current;
    const listbox = (_listRef$current = listRef.current) === null || _listRef$current === void 0 ? void 0 : _listRef$current.querySelector('.euiSelectableList__list');
    if (!listbox) return;
    const {
      scrollTop,
      scrollHeight,
      clientHeight
    } = listbox;
    if (scrollTop + clientHeight >= scrollHeight - parseInt(euiTheme.size.xxl, 10)) {
      // reached the "bottom" of the list, where euiSizeXXL acts as a "margin of error" so that the user doesn't
      // have to scroll **all the way** to the bottom in order to load more options
      stateManager.requestSize.next(Math.min(totalCardinality, _constants.MAX_OPTIONS_LIST_REQUEST_SIZE));
      api.loadMoreSubject.next(); // trigger refetch with loadMoreSubject
    }
  }, [api.loadMoreSubject, euiTheme.size.xxl, stateManager.requestSize, totalCardinality]);
  const renderOption = (0, _react.useCallback)((option, searchStringValue) => {
    if (!allowExpensiveQueries || searchTechnique === 'exact') return option.label;
    return /*#__PURE__*/_react.default.createElement(_eui.EuiHighlight, {
      search: option.key === 'exists-option' ? '' : searchStringValue
    }, option.label);
  }, [searchTechnique, allowExpensiveQueries]);
  (0, _react.useEffect)(() => {
    const container = listRef.current;
    if (!loading && canLoadMoreSuggestions) {
      container === null || container === void 0 ? void 0 : container.addEventListener('scroll', loadMoreOptions, true);
      return () => {
        container === null || container === void 0 ? void 0 : container.removeEventListener('scroll', loadMoreOptions, true);
      };
    }
  }, [loadMoreOptions, loading, canLoadMoreSuggestions]);
  (0, _react.useEffect)(() => {
    var _listRef$current2;
    // scroll back to the top when changing the sorting or the search string
    const listbox = (_listRef$current2 = listRef.current) === null || _listRef$current2 === void 0 ? void 0 : _listRef$current2.querySelector('.euiSelectableList__list');
    listbox === null || listbox === void 0 ? void 0 : listbox.scrollTo({
      top: 0
    });
  }, [sort, searchString]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    "data-test-subj": "optionsList--scrollListener",
    ref: listRef
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiSelectable, {
    options: selectableOptions,
    renderOption: option => renderOption(option, searchString),
    listProps: {
      onFocusBadge: false
    },
    "aria-label": _options_list_strings.OptionsListStrings.popover.getSuggestionsAriaLabel(fieldName, selectableOptions.length),
    emptyMessage: /*#__PURE__*/_react.default.createElement(_options_list_popover_empty_message.OptionsListPopoverEmptyMessage, {
      showOnlySelected: showOnlySelected
    }),
    onChange: (newSuggestions, event, changedOption) => {
      api.makeSelection(changedOption.key, showOnlySelected);
    }
  }, list => list)));
};
exports.OptionsListPopoverSuggestions = OptionsListPopoverSuggestions;