"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useHeaderActionMenuMounter = exports.HeaderActionMenu = void 0;
var _react = _interopRequireWildcard(require("react"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const useHeaderActionMenuMounter = actionMenu$ => {
  // useObservable relies on useState under the hood. The signature is type SetStateAction<S> = S | ((prevState: S) => S);
  // As we got a Observable<Function> here, React's setState setter assume he's getting a `(prevState: S) => S` signature,
  // therefore executing the mount method, causing everything to crash.
  // piping the observable before calling `useObservable` causes the effect to always having a new reference, as
  // the piped observable is a new instance on every render, causing infinite loops.
  // this is why we use `useLayoutEffect` manually here.
  const [mounter, setMounter] = (0, _react.useState)({
    mount: undefined
  });
  (0, _react.useLayoutEffect)(() => {
    const s = actionMenu$.subscribe(value => {
      setMounter({
        mount: value
      });
    });
    return () => s.unsubscribe();
  }, [actionMenu$]);
  return mounter;
};
exports.useHeaderActionMenuMounter = useHeaderActionMenuMounter;
const HeaderActionMenu = ({
  mounter
}) => {
  const elementRef = (0, _react.useRef)(null);
  const unmountRef = (0, _react.useRef)(null);
  (0, _react.useLayoutEffect)(() => {
    if (mounter.mount && elementRef.current) {
      try {
        unmountRef.current = mounter.mount(elementRef.current);
      } catch (e) {
        // TODO: use client-side logger when feature is implemented
        // eslint-disable-next-line no-console
        console.error(e);
      }
    }
    return () => {
      if (unmountRef.current) {
        unmountRef.current();
        unmountRef.current = null;
      }
    };
  }, [mounter]);
  return /*#__PURE__*/_react.default.createElement("div", {
    "data-test-subj": "headerAppActionMenu",
    ref: elementRef
  });
};
exports.HeaderActionMenu = HeaderActionMenu;