"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DashboardViewport = void 0;
var _classnames = _interopRequireDefault(require("classnames"));
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _public = require("@kbn/embeddable-plugin/public");
var _sharedUxButtonExitFullScreen = require("@kbn/shared-ux-button-exit-full-screen");
var _common = require("@kbn/controls-plugin/common");
var _presentationPublishing = require("@kbn/presentation-publishing");
var _grid = require("../grid");
var _use_dashboard_api = require("../../../dashboard_api/use_dashboard_api");
var _use_dashboard_internal_api = require("../../../dashboard_api/use_dashboard_internal_api");
var _dashboard_empty_screen = require("../empty_screen/dashboard_empty_screen");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const DashboardViewport = ({
  dashboardContainerRef
}) => {
  const dashboardApi = (0, _use_dashboard_api.useDashboardApi)();
  const dashboardInternalApi = (0, _use_dashboard_internal_api.useDashboardInternalApi)();
  const [hasControls, setHasControls] = (0, _react.useState)(false);
  const [controlGroupApi, dashboardTitle, description, expandedPanelId, panels, viewMode, useMargins, fullScreenMode] = (0, _presentationPublishing.useBatchedPublishingSubjects)(dashboardApi.controlGroupApi$, dashboardApi.title$, dashboardApi.description$, dashboardApi.expandedPanelId$, dashboardApi.panels$, dashboardApi.viewMode$, dashboardApi.settings.useMargins$, dashboardApi.fullScreenMode$);
  const onExit = (0, _react.useCallback)(() => {
    dashboardApi.setFullScreenMode(false);
  }, [dashboardApi]);
  const panelCount = (0, _react.useMemo)(() => {
    return Object.keys(panels).length;
  }, [panels]);
  const classes = (0, _classnames.default)({
    dshDashboardViewport: true,
    'dshDashboardViewport--print': viewMode === 'print',
    'dshDashboardViewport--panelExpanded': Boolean(expandedPanelId)
  });
  (0, _react.useEffect)(() => {
    if (!controlGroupApi) {
      return;
    }
    const subscription = controlGroupApi.children$.subscribe(children => {
      setHasControls(Object.keys(children).length > 0);
    });
    return () => {
      subscription.unsubscribe();
    };
  }, [controlGroupApi]);

  // Bug in main where panels are loaded before control filters are ready
  // Want to migrate to react embeddable controls with same behavior
  // TODO - do not load panels until control filters are ready
  /*
  const [dashboardInitialized, setDashboardInitialized] = useState(false);
  useEffect(() => {
    let ignore = false;
    dashboard.untilContainerInitialized().then(() => {
      if (!ignore) {
        setDashboardInitialized(true);
      }
    });
    return () => {
      ignore = true;
    };
  }, [dashboard]);
  */

  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)('dshDashboardViewportWrapper', {
      'dshDashboardViewportWrapper--defaultBg': !useMargins
    })
  }, viewMode !== 'print' ? /*#__PURE__*/_react.default.createElement("div", {
    className: hasControls ? 'dshDashboardViewport-controls' : ''
  }, /*#__PURE__*/_react.default.createElement(_public.ReactEmbeddableRenderer, {
    key: dashboardApi.uuid,
    hidePanelChrome: true,
    panelProps: {
      hideLoader: true
    },
    type: _common.CONTROL_GROUP_TYPE,
    maybeId: 'control_group',
    getParentApi: () => {
      return {
        ...dashboardApi,
        reload$: dashboardInternalApi.controlGroupReload$,
        getSerializedStateForChild: dashboardInternalApi.getSerializedStateForControlGroup,
        getRuntimeStateForChild: dashboardInternalApi.getRuntimeStateForControlGroup
      };
    },
    onApiAvailable: api => dashboardInternalApi.setControlGroupApi(api)
  })) : null, fullScreenMode && /*#__PURE__*/_react.default.createElement(_eui.EuiPortal, null, /*#__PURE__*/_react.default.createElement(_sharedUxButtonExitFullScreen.ExitFullScreenButton, {
    onExit: onExit,
    toggleChrome: !dashboardApi.isEmbeddedExternally
  })), panelCount === 0 && /*#__PURE__*/_react.default.createElement(_dashboard_empty_screen.DashboardEmptyScreen, null), /*#__PURE__*/_react.default.createElement("div", {
    className: classes,
    "data-shared-items-container": true,
    "data-title": dashboardTitle,
    "data-description": description,
    "data-shared-items-count": panelCount
  }, /*#__PURE__*/_react.default.createElement(_grid.DashboardGrid, {
    dashboardContainerRef: dashboardContainerRef
  })));
};
exports.DashboardViewport = DashboardViewport;