"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDeleteActionDescriptor = void 0;
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
var _react = _interopRequireWildcard(require("react"));
var _reactKibanaMount = require("@kbn/react-kibana-mount");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const DeleteConfirm = props => {
  const {
    searchSession,
    api,
    onActionDismiss
  } = props;
  const {
    name,
    id
  } = searchSession;
  const [isLoading, setIsLoading] = (0, _react.useState)(false);
  const title = _i18n.i18n.translate('data.mgmt.searchSessions.cancelModal.title', {
    defaultMessage: 'Delete search session'
  });
  const confirm = _i18n.i18n.translate('data.mgmt.searchSessions.cancelModal.deleteButton', {
    defaultMessage: 'Delete'
  });
  const cancel = _i18n.i18n.translate('data.mgmt.searchSessions.cancelModal.cancelButton', {
    defaultMessage: 'Cancel'
  });
  const message = _i18n.i18n.translate('data.mgmt.searchSessions.cancelModal.message', {
    defaultMessage: `Deleting the search session ''{name}'' deletes all cached results.`,
    values: {
      name
    }
  });
  return /*#__PURE__*/_react.default.createElement(_eui.EuiConfirmModal, {
    title: title,
    onCancel: onActionDismiss,
    onConfirm: async () => {
      setIsLoading(true);
      await api.sendDelete(id);
      onActionDismiss();
    },
    confirmButtonText: confirm,
    confirmButtonDisabled: isLoading,
    cancelButtonText: cancel,
    defaultFocusedButton: "confirm",
    buttonColor: "danger"
  }, message);
};
const createDeleteActionDescriptor = (api, uiSession, core) => ({
  iconType: 'trash',
  label: /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "data.mgmt.searchSessions.actionDelete",
    defaultMessage: "Delete"
  }),
  onClick: async () => {
    const ref = core.overlays.openModal((0, _reactKibanaMount.toMountPoint)(/*#__PURE__*/_react.default.createElement(DeleteConfirm, {
      onActionDismiss: () => ref === null || ref === void 0 ? void 0 : ref.close(),
      searchSession: uiSession,
      api: api
    }), core));
    await ref.onClose;
  }
});
exports.createDeleteActionDescriptor = createDeleteActionDescriptor;