"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toAsyncKibanaSearchResponse = toAsyncKibanaSearchResponse;
var _sanitize_request_params = require("../../sanitize_request_params");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

/**
 * Get the Kibana representation of an async search response (see `IKibanaSearchResponse`).
 */
function toAsyncKibanaSearchResponse(response, headers, requestParams) {
  const responseIsStream = response.id === undefined;
  return {
    id: responseIsStream ? headers['x-elasticsearch-async-id'] : response.id,
    rawResponse: response,
    isRunning: responseIsStream ? headers['x-elasticsearch-async-is-running'] === '?1' : response.is_running,
    isPartial: responseIsStream ? headers['x-elasticsearch-async-is-partial'] === '?1' : response.is_partial,
    ...(headers !== null && headers !== void 0 && headers.warning ? {
      warning: headers === null || headers === void 0 ? void 0 : headers.warning
    } : {}),
    ...(requestParams ? {
      requestParams: (0, _sanitize_request_params.sanitizeRequestParams)(requestParams)
    } : {})
  };
}