"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EmbeddablePublicPlugin = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _common = require("@kbn/kibana-utils-plugin/common");
var _register_triggers = require("./ui_actions/register_triggers");
var _state_transfer = require("./state_transfer");
var _lib = require("../common/lib");
var _get_all_migrations = require("../common/lib/get_all_migrations");
var _kibana_services = require("./kibana_services");
var _react_embeddable_system = require("./react_embeddable_system");
var _registry = require("./add_from_library/registry");
var _registry2 = require("./enhancements/registry");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

class EmbeddablePublicPlugin {
  constructor(initializerContext) {
    (0, _defineProperty2.default)(this, "stateTransferService", {});
    (0, _defineProperty2.default)(this, "appList", void 0);
    (0, _defineProperty2.default)(this, "appListSubscription", void 0);
    (0, _defineProperty2.default)(this, "enhancementsRegistry", new _registry2.EnhancementsRegistry());
  }
  setup(core, {
    uiActions
  }) {
    (0, _register_triggers.registerTriggers)(uiActions);
    return {
      registerReactEmbeddableFactory: _react_embeddable_system.registerReactEmbeddableFactory,
      registerAddFromLibraryType: _registry.registerAddFromLibraryType,
      registerEnhancement: this.enhancementsRegistry.registerEnhancement
    };
  }
  start(core, deps) {
    this.appListSubscription = core.application.applications$.subscribe(appList => {
      this.appList = appList;
    });
    this.stateTransferService = new _state_transfer.EmbeddableStateTransfer(core.application.navigateToApp, core.application.currentAppId$, this.appList);
    const commonContract = {
      getEnhancement: this.enhancementsRegistry.getEnhancement
    };
    const getAllMigrationsFn = () => (0, _get_all_migrations.getAllMigrations)([], this.enhancementsRegistry.getEnhancements(), (0, _lib.getMigrateFunction)(commonContract));
    const embeddableStart = {
      getStateTransfer: storage => storage ? new _state_transfer.EmbeddableStateTransfer(core.application.navigateToApp, core.application.currentAppId$, this.appList, storage) : this.stateTransferService,
      telemetry: (0, _lib.getTelemetryFunction)(commonContract),
      extract: (0, _lib.getExtractFunction)(commonContract),
      inject: (0, _lib.getInjectFunction)(commonContract),
      getAllMigrations: getAllMigrationsFn,
      migrateToLatest: state => {
        return (0, _common.migrateToLatest)(getAllMigrationsFn(), state);
      }
    };
    (0, _kibana_services.setKibanaServices)(core, embeddableStart, deps);
    return embeddableStart;
  }
  stop() {
    if (this.appListSubscription) {
      this.appListSubscription.unsubscribe();
    }
  }
}
exports.EmbeddablePublicPlugin = EmbeddablePublicPlugin;