"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerTelemetryRoute = registerTelemetryRoute;
var _configSchema = require("@kbn/config-schema");
var _telemetry = require("../../collectors/enterprise_search/telemetry");
var _telemetry2 = require("../../collectors/lib/telemetry");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const productToTelemetryMap = {
  enterprise_search: _telemetry.ES_TELEMETRY_NAME
};
function registerTelemetryRoute({
  router,
  getSavedObjectsService
}) {
  router.put({
    path: '/internal/enterprise_search/stats',
    security: {
      authz: {
        enabled: false,
        reason: 'This route delegates authorization to the scoped ES client'
      }
    },
    validate: {
      body: _configSchema.schema.object({
        product: _configSchema.schema.oneOf([_configSchema.schema.literal('enterprise_search')]),
        action: _configSchema.schema.oneOf([_configSchema.schema.literal('viewed'), _configSchema.schema.literal('clicked'), _configSchema.schema.literal('error')]),
        metric: _configSchema.schema.string()
      })
    }
  }, async (ctx, request, response) => {
    const {
      product,
      action,
      metric
    } = request.body;
    if (!getSavedObjectsService) throw new Error('Could not find Saved Objects service');
    return response.ok({
      body: await (0, _telemetry2.incrementUICounter)({
        id: productToTelemetryMap[product],
        savedObjects: getSavedObjectsService(),
        uiAction: `ui_${action}`,
        metric
      })
    });
  });
}