"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerGetJoinIndicesRoute = void 0;
var _esql_service = require("../services/esql_service");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the "Elastic License
 * 2.0", the "GNU Affero General Public License v3.0 only", and the "Server Side
 * Public License v 1"; you may not use this file except in compliance with, at
 * your election, the "Elastic License 2.0", the "GNU Affero General Public
 * License v3.0 only", or the "Server Side Public License, v 1".
 */

const registerGetJoinIndicesRoute = (router, {
  logger
}) => {
  router.get({
    path: '/internal/esql/autocomplete/join/indices',
    validate: {},
    security: {
      authz: {
        enabled: false,
        reason: 'This route delegates authorization to the scoped ES client'
      }
    }
  }, async (requestHandlerContext, request, response) => {
    try {
      const core = await requestHandlerContext.core;
      const service = new _esql_service.EsqlService({
        client: core.elasticsearch.client.asCurrentUser
      });
      const result = await service.getJoinIndices();
      return response.ok({
        body: result
      });
    } catch (error) {
      logger.get().debug(error);
      throw error;
    }
  });
};
exports.registerGetJoinIndicesRoute = registerGetJoinIndicesRoute;