"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ControlsContent = void 0;
var _public = require("@kbn/controls-plugin/public");
var _styled = _interopRequireDefault(require("@emotion/styled"));
var _public2 = require("@kbn/observability-shared-plugin/public");
var _react = _interopRequireWildcard(require("react"));
var _rxjs = require("rxjs");
var _control_panels_config = require("./control_panels_config");
var _controls_title = require("./controls_title");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const ControlsContent = ({
  dataView,
  filters,
  query,
  timeRange,
  onFiltersChange
}) => {
  const [controlPanels, setControlPanels] = (0, _public2.useControlPanels)(_control_panels_config.controlPanelConfigs, dataView);
  const subscriptions = (0, _react.useRef)(new _rxjs.Subscription());
  const getInitialInput = (0, _react.useCallback)(() => async () => {
    const initialInput = {
      chainingSystem: 'HIERARCHICAL',
      labelPosition: 'oneLine',
      initialChildControlState: controlPanels
    };
    return {
      initialState: initialInput
    };
  }, [controlPanels]);
  const loadCompleteHandler = (0, _react.useCallback)(controlGroup => {
    if (!controlGroup) return;
    controlGroup.untilInitialized().then(() => {
      const children = controlGroup.children$.getValue();
      Object.keys(children).map(childId => {
        const child = children[childId];
        child.CustomPrependComponent = () => /*#__PURE__*/_react.default.createElement(_controls_title.ControlTitle, {
          title: child.title$.getValue(),
          embeddableId: childId
        });
      });
    });
    subscriptions.current.add(controlGroup.filters$.subscribe((newFilters = []) => {
      onFiltersChange(newFilters);
    }));
    subscriptions.current.add(controlGroup.getInput$().subscribe(({
      initialChildControlState
    }) => setControlPanels(initialChildControlState)));
  }, [onFiltersChange, setControlPanels]);
  (0, _react.useEffect)(() => {
    const currentSubscriptions = subscriptions.current;
    return () => {
      currentSubscriptions.unsubscribe();
    };
  }, []);
  if (!dataView) {
    return null;
  }
  return /*#__PURE__*/_react.default.createElement(ControlGroupContainer, null, /*#__PURE__*/_react.default.createElement(_public.ControlGroupRenderer, {
    getCreationOptions: getInitialInput(),
    onApiAvailable: loadCompleteHandler,
    timeRange: timeRange,
    query: query,
    filters: filters
  }));
};
exports.ControlsContent = ControlsContent;
const ControlGroupContainer = _styled.default.div`
  .controlGroup {
    min-height: ${props => props.theme.euiTheme.size.xxl};
  }
`;