"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useInfluencersListStyles = void 0;
var _react = require("@emotion/react");
var _eui = require("@elastic/eui");
var _mlAnomalyUtils = require("@kbn/ml-anomaly-utils");
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const useInfluencersListStyles = () => {
  const {
    euiTheme
  } = (0, _eui.useEuiTheme)();
  const euiFontSizeXS = (0, _eui.useEuiFontSize)('xs').fontSize;
  const euiFontSizeS = (0, _eui.useEuiFontSize)('s').fontSize;
  return {
    influencersList: (0, _react.css)({
      lineHeight: 1.45
    }),
    fieldLabel: (0, _react.css)({
      fontSize: euiFontSizeXS,
      textAlign: 'left',
      maxHeight: euiFontSizeS,
      maxWidth: 'calc(100% - 102px)'
    }),
    progress: (0, _react.css)({
      display: 'inline-block',
      width: 'calc(100% - 34px)',
      height: '22px',
      minWidth: '70px',
      marginBottom: 0,
      color: euiTheme.colors.darkShade,
      backgroundColor: 'transparent'
    }),
    progressBarHolder: (0, _react.css)({
      width: `calc(100% - 28px)`
    }),
    progressBar: (severity, barScore) => (0, _react.css)({
      height: `calc(${euiTheme.size.xs} / 2)`,
      float: 'left',
      marginTop: euiTheme.size.m,
      textAlign: 'right',
      lineHeight: '18px',
      display: 'inline-block',
      transition: 'none',
      width: `${barScore}%`,
      backgroundColor: severity === 'critical' ? _mlAnomalyUtils.ML_SEVERITY_COLORS.CRITICAL : severity === 'major' ? _mlAnomalyUtils.ML_SEVERITY_COLORS.MAJOR : severity === 'minor' ? _mlAnomalyUtils.ML_SEVERITY_COLORS.MINOR : _mlAnomalyUtils.ML_SEVERITY_COLORS.WARNING
    }),
    scoreLabel: severity => (0, _react.css)({
      textAlign: 'center',
      lineHeight: '14px',
      whiteSpace: 'nowrap',
      fontSize: euiFontSizeXS,
      marginLeft: euiTheme.size.xs,
      display: 'inline',
      borderColor: severity === 'critical' ? _mlAnomalyUtils.ML_SEVERITY_COLORS.CRITICAL : severity === 'major' ? _mlAnomalyUtils.ML_SEVERITY_COLORS.MAJOR : severity === 'minor' ? _mlAnomalyUtils.ML_SEVERITY_COLORS.MINOR : _mlAnomalyUtils.ML_SEVERITY_COLORS.WARNING
    }),
    totalScoreLabel: (0, _react.css)({
      width: euiTheme.size.xl,
      verticalAlign: 'top',
      textAlign: 'center',
      color: euiTheme.colors.darkShade,
      fontSize: '11px',
      lineHeight: '14px',
      borderRadius: euiTheme.border.radius.small,
      padding: `calc(${euiTheme.size.xs} / 2)`,
      display: 'inline-block',
      border: euiTheme.border.thin
    })
  };
};
exports.useInfluencersListStyles = useInfluencersListStyles;