"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.JobSelector = JobSelector;
exports.getInitialGroupsMap = getInitialGroupsMap;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18n = require("@kbn/i18n");
var _i18nReact = require("@kbn/i18n-react");
require("./_index.scss");
var _locator = require("../../../locator");
var _id_badges = require("./id_badges");
var _job_selector_flyout = require("./job_selector_flyout");
var _feedback_button = require("../feedback_button");
var _job_details_flyout = require("../../jobs/components/job_details_flyout");
var _job_details_context_manager = require("../../jobs/components/job_details_flyout/job_details_context_manager");
var _use_job_selection_flyout = require("../../contexts/ml/use_job_selection_flyout");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

function mergeSelection(jobIds, groupObjs, singleSelection) {
  if (singleSelection) {
    return jobIds;
  }
  const selectedIds = [];
  const alreadySelected = [];
  groupObjs.forEach(group => {
    selectedIds.push(group.groupId);
    alreadySelected.push(...group.jobIds);
  });
  jobIds.forEach(jobId => {
    // Add jobId if not already included in group selection
    if (alreadySelected.includes(jobId) === false) {
      selectedIds.push(jobId);
    }
  });
  return selectedIds;
}
function getInitialGroupsMap(selectedGroups) {
  const map = {};
  if (selectedGroups.length) {
    selectedGroups.forEach(group => {
      map[group.groupId] = group.jobIds;
    });
  }
  return map;
}
function JobSelector({
  dateFormatTz,
  singleSelection,
  timeseriesOnly,
  selectedJobIds = [],
  selectedGroups = [],
  selectedJobs = [],
  onSelectionChange
}) {
  const [selectedIds, setSelectedIds] = (0, _react.useState)(mergeSelection(selectedJobIds, selectedGroups, singleSelection));
  const [showAllBarBadges, setShowAllBarBadges] = (0, _react.useState)(false);
  const openJobSelectionFlyout = (0, _use_job_selection_flyout.useJobSelectionFlyout)();

  // Ensure JobSelectionBar gets updated when selection via globalState changes.
  (0, _react.useEffect)(() => {
    setSelectedIds(mergeSelection(selectedJobIds, selectedGroups, singleSelection));
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [JSON.stringify([selectedJobIds, selectedGroups])]);
  const handleJobSelectionClick = (0, _react.useCallback)(async () => {
    try {
      const result = await openJobSelectionFlyout({
        singleSelection,
        withTimeRangeSelector: true,
        timeseriesOnly,
        selectedIds
      });
      if (result) {
        const {
          newSelection,
          jobIds,
          time
        } = result;
        setSelectedIds(newSelection);
        onSelectionChange === null || onSelectionChange === void 0 ? void 0 : onSelectionChange({
          jobIds,
          time
        });
      }
    } catch {
      // Flyout closed without selection
    }
  }, [onSelectionChange, openJobSelectionFlyout, selectedIds, singleSelection, timeseriesOnly]);
  const page = (0, _react.useMemo)(() => {
    return singleSelection ? _locator.ML_PAGES.SINGLE_METRIC_VIEWER : _locator.ML_PAGES.ANOMALY_EXPLORER;
  }, [singleSelection]);
  const removeJobId = jobOrGroupId => {
    const newSelection = selectedIds.filter(id => !jobOrGroupId.includes(id));
    setSelectedIds(newSelection);
    onSelectionChange === null || onSelectionChange === void 0 ? void 0 : onSelectionChange({
      jobIds: newSelection,
      time: undefined
    });
  };
  function renderJobSelectionBar() {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      responsive: false,
      gutterSize: "xs",
      alignItems: "center"
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, selectedIds.length > 0 ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, {
      wrap: true,
      responsive: false,
      gutterSize: "xs",
      alignItems: "center",
      "data-test-subj": "mlJobSelectionBadges"
    }, /*#__PURE__*/_react.default.createElement(_id_badges.IdBadges, {
      limit: _job_selector_flyout.BADGE_LIMIT,
      onLinkClick: () => setShowAllBarBadges(!showAllBarBadges),
      selectedJobIds: selectedJobIds,
      selectedGroups: selectedGroups,
      selectedJobs: selectedJobs,
      showAllBarBadges: showAllBarBadges,
      page: page,
      onRemoveJobId: removeJobId
    })) : /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
      id: "xpack.ml.jobSelector.noJobsSelectedLabel",
      defaultMessage: "No jobs selected"
    }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
      size: "xs",
      iconType: "pencil",
      onClick: handleJobSelectionClick,
      "data-test-subj": "mlButtonEditJobSelection"
    }, _i18n.i18n.translate('xpack.ml.jobSelector.jobSelectionButton', {
      defaultMessage: 'Edit job selection'
    }))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, null), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
      grow: false
    }, /*#__PURE__*/_react.default.createElement(_feedback_button.FeedBackButton, {
      jobIds: selectedIds,
      page: page
    }))), /*#__PURE__*/_react.default.createElement(_eui.EuiHorizontalRule, {
      margin: "s"
    }));
  }
  return /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_job_details_flyout.JobInfoFlyoutsProvider, null, renderJobSelectionBar(), /*#__PURE__*/_react.default.createElement(_job_details_context_manager.JobInfoFlyoutsManager, null)));
}