"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AnalyticsDetailFlyout = void 0;
var _react = _interopRequireWildcard(require("react"));
var _eui = require("@elastic/eui");
var _i18nReact = require("@kbn/i18n-react");
var _mlUrlState = require("@kbn/ml-url-state");
var _job_details_flyout = require("../../../../../jobs/components/job_details_flyout");
var _analytics_service = require("../../../analytics_management/services/analytics_service");
var _kibana = require("../../../../../contexts/kibana");
var _locator = require("../../../../../../locator");
var _expanded_row = require("../../../analytics_management/components/analytics_list/expanded_row");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

const AnalyticsDetailFlyout = () => {
  var _globalState$ml2;
  const {
    isDataFrameAnalyticsDetailsFlyoutOpen,
    closeActiveFlyout,
    setActiveJobId,
    activeJobId: analyticsId
  } = (0, _job_details_flyout.useJobInfoFlyouts)();
  const [analytics, setAnalytics] = (0, _react.useState)([]);
  const [, setAnalyticsStats] = (0, _react.useState)(undefined);
  const [, setErrorMessage] = (0, _react.useState)(undefined);
  const [, setIsInitialized] = (0, _react.useState)(false);
  const [, setJobsAwaitingNodeCount] = (0, _react.useState)(0);
  const blockRefresh = false;
  const getAnalytics = (0, _analytics_service.useGetAnalytics)(setAnalytics, setAnalyticsStats, setErrorMessage, setIsInitialized, setJobsAwaitingNodeCount, blockRefresh);
  const getAnalyticsCallback = (0, _react.useCallback)(id => getAnalytics(true, id), [getAnalytics]);

  // Subscribe to the refresh observable to trigger reloading the analytics list.

  (0, _react.useEffect)(function getAnalyticsDetailsOnChange() {
    if (!analyticsId) {
      return;
    }
    getAnalyticsCallback(analyticsId);
  },
  // eslint-disable-next-line react-hooks/exhaustive-deps
  [analyticsId]);
  const analytic = (0, _react.useMemo)(() => analytics.find(a => a.id === analyticsId), [analytics, analyticsId]);
  const locator = (0, _kibana.useMlLocator)();
  const navigateToPath = (0, _kibana.useNavigateToPath)();
  const [globalState] = (0, _mlUrlState.useUrlState)('_g');
  const redirectToAnalyticsList = (0, _react.useCallback)(async () => {
    var _globalState$ml;
    const path = await locator.getUrl({
      page: _locator.ML_PAGES.DATA_FRAME_ANALYTICS_JOBS_MANAGE,
      pageState: {
        jobId: globalState === null || globalState === void 0 ? void 0 : (_globalState$ml = globalState.ml) === null || _globalState$ml === void 0 ? void 0 : _globalState$ml.jobId
      }
    });
    await navigateToPath(path, false);
  }, [locator, navigateToPath, globalState === null || globalState === void 0 ? void 0 : (_globalState$ml2 = globalState.ml) === null || _globalState$ml2 === void 0 ? void 0 : _globalState$ml2.jobId]);
  const flyoutTitleId = `mlAnalyticsDetailsFlyout-${analyticsId}`;
  return isDataFrameAnalyticsDetailsFlyoutOpen ? /*#__PURE__*/_react.default.createElement(_eui.EuiFlyout, {
    "data-test-subj": "analyticsDetailsFlyout",
    type: "overlay",
    size: "m",
    ownFocus: false,
    onClose: () => {
      closeActiveFlyout();
      setActiveJobId(null);
    },
    "aria-labelledby": flyoutTitleId
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutHeader, {
    hasBorder: true,
    "data-test-subj": `analyticsDetailsFlyout-${analyticsId}`
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexGroup, null, /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: true
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiTitle, {
    size: "s"
  }, /*#__PURE__*/_react.default.createElement("h2", {
    id: flyoutTitleId
  }, analyticsId))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlexItem, {
    grow: false
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiButtonEmpty, {
    onClick: redirectToAnalyticsList
  }, /*#__PURE__*/_react.default.createElement(_i18nReact.FormattedMessage, {
    id: "xpack.ml.jobDetailsFlyout.openJobsListButton",
    defaultMessage: "Open jobs list"
  }))))), /*#__PURE__*/_react.default.createElement(_eui.EuiFlyoutBody, null, analytic ? /*#__PURE__*/_react.default.createElement(_expanded_row.ExpandedRow, {
    item: analytic
  }) : /*#__PURE__*/_react.default.createElement(_eui.EuiText, {
    textAlign: "center"
  }, /*#__PURE__*/_react.default.createElement(_eui.EuiLoadingSpinner, null)))) : null;
};
exports.AnalyticsDetailFlyout = AnalyticsDetailFlyout;